#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_dj-chartjs
------------

Tests for `dj-chartjs` models module.
"""

from django.test import TestCase

from dj_chartjs import models


class TestDj_chartjs(TestCase):
    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
